Base Classes
============

The base classes are inherited by various PSO implementations throughout the library.
It supports a simple skeleton to construct a customized PSO algorithm. 

.. toctree::

   pyswarms.base
